@@ -4,7 +4,7 @@ Config::Neat::Util - Common utility functions for other Config::Neat modules
 
 =head1 COPYRIGHT
 
-Copyright (C) 2012-2014 Igor Afanasyev <igor.afanasyev@gmail.com>
+Copyright (C) 2012-2015 Igor Afanasyev <igor.afanasyev@gmail.com>
 
 =head1 SEE ALSO
 
@@ -14,7 +14,7 @@ L<https://github.com/iafan/Config-Neat>
 
 package Config::Neat::Util;
 
-our $VERSION = '1.101';
+our $VERSION = '1.2';
 
 use strict;
 
@@ -63,7 +63,7 @@ sub to_ixhash {
 
 sub is_number {
     my $n = shift;
-    return ($n + 0) eq $n;
+    return defined $n && $n =~ m/^\d+$/;
 }
 
 sub is_code {
@@ -169,7 +169,7 @@ sub get_next_auto_key {
     # get max(key)
     my $i = -1; # so that next key will start with 0
     map {
-        $i = $_ if $_ > $i && is_number($_);
+        $i = $_ if is_number($_) && $_ > $i;
     } keys %$node;
 
     # return max + 1
